@@ -9,15 +9,18 @@
  * @package Fishers_Theme
  */
 
+$video_source = $media_item_data['video_source'];
 $size = $media_item_data['size'];
 $video = $media_item_data['video'];
+$video_media_lib = $media_item_data['video_from_media_library'];
+$video = \Blue2\Scruffy\Controllers\OEmbedController::filterEmbed($video);
 $thumb = $media_item_data['thumb'];
 
 // if a custom thumbnail is set, replace oEmbed one
 if ($thumb) {
     $video = preg_replace(
         '/(.*?)<img src=\'.*?\'(.*?)/i',
-        '$1<img src=\'' . home_url($thumb['url']) . '\'$2',
+        '$1<img src=\'' . $thumb['url'] . '\'$2',
         $video
     );
 }
@@ -26,5 +29,15 @@ if ($thumb) {
 
 <div class="s-media__item s-media__item--<?= $size; ?>">
     <h3 class="d-md-none ff-alt fw-medium fs-8 text-white mb-2">Fishers latest Video</h3>
-    <?= $video; ?>
+    <?php
+        if($video_source){
+          ?>
+          <video controls>
+              <source src="<?= $video_media_lib; ?>" type="video/mp4">
+          </video>
+          <?php  
+        }else{
+            echo $video;
+        }
+    ?>
 </div>
